@@ -1,10 +1,8 @@
 mod boolean;
 mod rev;
 
-use crate::utils::{FromTrustedLenIterator, TrustMyLength};
+use crate::utils::TrustMyLength;
 use arrow::bitmap::utils::{BitmapIter, ZipValidity};
-use arrow::buffer::MutableBuffer;
-use arrow::types::NativeType;
 pub use rev::FromIteratorReversed;
 use std::slice::Iter;
 
@@ -63,15 +61,6 @@ unsafe impl<T, I: TrustedLen + Iterator<Item = T>> TrustedLen for ZipValidity<'_
 unsafe impl TrustedLen for BitmapIter<'_> {}
 unsafe impl<A: TrustedLen> TrustedLen for std::iter::StepBy<A> {}
 
-impl<T: arrow::types::NativeType> FromTrustedLenIterator<T> for MutableBuffer<T> {
-    fn from_iter_trusted_length<I: IntoIterator<Item = T>>(iter: I) -> Self {
-        let iter = iter.into_iter();
-        // Safety:
-        // Guarded by trait system
-        unsafe { MutableBuffer::from_trusted_len_iter_unchecked(iter) }
-    }
-}
-
 pub trait PushUnchecked<T> {
     /// Will push an item and not check if there is enough capacity
     ///
@@ -87,34 +76,8 @@ pub trait PushUnchecked<T> {
 
     /// Extend the array with an iterator who's length can be trusted
     fn extend_trusted_len<I: IntoIterator<Item = T> + TrustedLen>(&mut self, iter: I);
-}
 
-impl<T: NativeType> PushUnchecked<T> for MutableBuffer<T> {
-    unsafe fn push_unchecked(&mut self, value: T) {
-        let end = self.as_mut_ptr().add(self.len());
-        std::ptr::write(end, value);
-        self.set_len(self.len() + 1);
-    }
-
-    unsafe fn push_unchecked_no_len_set(&mut self, value: T) {
-        let end = self.as_mut_ptr().add(self.len());
-        std::ptr::write(end, value);
-    }
-
-    fn extend_trusted_len<I: IntoIterator<Item = T> + TrustedLen>(&mut self, iter: I) {
-        let iter = iter.into_iter();
-        let upper = iter.size_hint().1.expect("must have an upper bound");
-        self.reserve(upper);
-
-        unsafe {
-            let mut dst = self.as_mut_ptr().add(self.len());
-            for value in iter {
-                std::ptr::write(dst, value);
-                dst = dst.add(1)
-            }
-            self.set_len(self.len() + upper)
-        }
-    }
+    fn from_trusted_len_iter<I: IntoIterator<Item = T> + TrustedLen>(iter: I) -> Self;
 }
 
 impl<T> PushUnchecked<T> for Vec<T> {
@@ -146,4 +109,10 @@ impl<T> PushUnchecked<T> for Vec<T> {
             self.set_len(self.len() + upper)
         }
     }
+
+    fn from_trusted_len_iter<I: IntoIterator<Item = T> + TrustedLen>(iter: I) -> Self {
+        let mut v = vec![];
+        v.extend_trusted_len(iter);
+        v
+    }
 }
