@@ -2,7 +2,7 @@
 #[cfg(feature = "dtype-categorical")]
 use crate::chunked_array::categorical::CategoricalChunkedBuilder;
 use crate::prelude::*;
-use arrow::compute::cast;
+use polars_arrow::compute::cast;
 use std::convert::TryFrom;
 
 pub(crate) fn cast_chunks(chunks: &[ArrayRef], dtype: &DataType) -> Result<Vec<ArrayRef>> {
@@ -39,7 +39,7 @@ impl ChunkCast for CategoricalChunked {
 
                 let f = |idx: u32| mapping.get(idx);
 
-                if self.null_count() == 0 {
+                if !self.has_validity() {
                     self.into_no_null_iter()
                         .for_each(|idx| builder.append_value(f(idx)));
                 } else {
@@ -167,7 +167,7 @@ mod test {
     #[cfg(feature = "dtype-categorical")]
     fn test_cast_noop() {
         // check if we can cast categorical twice without panic
-        let ca = Utf8Chunked::new_from_slice("foo", &["bar", "ham"]);
+        let ca = Utf8Chunked::new("foo", &["bar", "ham"]);
         let out = ca.cast(&DataType::Categorical).unwrap();
         let out = out.cast(&DataType::Categorical).unwrap();
         assert_eq!(out.dtype(), &DataType::Categorical)
