@@ -1,7 +1,7 @@
 use crate::prelude::*;
 
 #[cfg(any(feature = "dtype-date", feature = "dtype-datetime"))]
-use arrow::temporal_conversions::{date32_to_date, timestamp_ms_to_datetime};
+use arrow::temporal_conversions::{date32_to_date, timestamp_ns_to_datetime};
 use num::{Num, NumCast};
 use std::{
     fmt,
@@ -501,14 +501,14 @@ impl Display for AnyValue<'_> {
             AnyValue::Float32(v) => fmt_float(f, width, *v),
             AnyValue::Float64(v) => fmt_float(f, width, *v),
             AnyValue::Boolean(v) => write!(f, "{}", *v),
-            AnyValue::Utf8(v) => write!(f, "{}", format!("\"{}\"", v)),
+            AnyValue::Utf8(v) => write!(f, "{}", format_args!("\"{}\"", v)),
             #[cfg(feature = "dtype-date")]
             AnyValue::Date(v) => write!(f, "{}", date32_to_date(*v)),
             #[cfg(feature = "dtype-datetime")]
-            AnyValue::Datetime(v) => write!(f, "{}", timestamp_ms_to_datetime(*v)),
+            AnyValue::Datetime(v) => write!(f, "{}", timestamp_ns_to_datetime(*v)),
             #[cfg(feature = "dtype-time")]
             AnyValue::Time(_) => {
-                let nt: chrono::NaiveTime = self.into();
+                let nt: polars_time::export::chrono::NaiveTime = self.into();
                 write!(f, "{}", nt)
             }
             #[cfg(feature = "dtype-categorical")]
@@ -606,9 +606,9 @@ impl FmtList for TimeChunked {
 }
 
 #[cfg(feature = "object")]
-impl<T> FmtList for ObjectChunked<T> {
+impl<T: PolarsObject> FmtList for ObjectChunked<T> {
     fn fmt_list(&self) -> String {
-        todo!()
+        impl_fmt_list!(self)
     }
 }
 
@@ -642,7 +642,7 @@ Series: 'a' [list]
 
     #[test]
     fn test_fmt_temporal() {
-        let s = Int32Chunked::new_from_opt_slice("Date", &[Some(1), None, Some(3)]).into_date();
+        let s = Int32Chunked::new("Date", &[Some(1), None, Some(3)]).into_date();
         assert_eq!(
             r#"shape: (3,)
 Series: 'Date' [date]
@@ -654,15 +654,14 @@ Series: 'Date' [date]
             format!("{:?}", s.into_series())
         );
 
-        let s = Int64Chunked::new_from_opt_slice("", &[Some(1), None, Some(1_000_000_000_000)])
-            .into_date();
+        let s = Int64Chunked::new("", &[Some(1), None, Some(1_000_000_000_000)]).into_date();
         assert_eq!(
             r#"shape: (3,)
 Series: '' [datetime]
 [
-	1970-01-01 00:00:00.001
+	1970-01-01 00:00:00.000000001
 	null
-	2001-09-09 01:46:40
+	1970-01-01 00:16:40
 ]"#,
             format!("{:?}", s.into_series())
         );
@@ -670,7 +669,7 @@ Series: '' [datetime]
 
     #[test]
     fn test_fmt_chunkedarray() {
-        let ca = Int32Chunked::new_from_opt_slice("Date", &[Some(1), None, Some(3)]);
+        let ca = Int32Chunked::new("Date", &[Some(1), None, Some(3)]);
         println!("{:?}", ca);
         assert_eq!(
             r#"shape: (3,)
@@ -682,7 +681,7 @@ ChunkedArray: 'Date' [Int32]
 ]"#,
             format!("{:?}", ca)
         );
-        let ca = Utf8Chunked::new_from_slice("name", &["a", "b"]);
+        let ca = Utf8Chunked::new("name", &["a", "b"]);
         println!("{:?}", ca);
         assert_eq!(
             r#"shape: (2,)
