@@ -1,11 +1,12 @@
 //! DataFrame module.
 use std::borrow::Cow;
 use std::collections::HashSet;
-use std::iter::Iterator;
+use std::iter::{FromIterator, Iterator};
 use std::mem;
+use std::ops;
 use std::sync::Arc;
 
-use ahash::RandomState;
+use ahash::{AHashSet, RandomState};
 use arrow::record_batch::RecordBatch;
 use itertools::Itertools;
 use rayon::prelude::*;
@@ -135,22 +136,12 @@ fn duplicate_err(name: &str) -> Result<()> {
 
 impl DataFrame {
     /// Get the index of the column.
-    fn name_to_idx(&self, name: &str) -> Result<usize> {
-        let mut idx = 0;
-        for column in &self.columns {
-            if column.name() == name {
-                break;
-            }
-            idx += 1;
-        }
-        if idx == self.columns.len() {
-            Err(PolarsError::NotFound(name.into()))
-        } else {
-            Ok(idx)
-        }
+    fn check_name_to_idx(&self, name: &str) -> Result<usize> {
+        self.find_idx_by_name(name)
+            .ok_or_else(|| PolarsError::NotFound(name.into()))
     }
 
-    fn has_column(&self, name: &str) -> Result<()> {
+    fn check_already_present(&self, name: &str) -> Result<()> {
         if self.columns.iter().any(|s| s.name() == name) {
             Err(PolarsError::Duplicate(
                 format!("column with name: '{}' already present in DataFrame", name).into(),
@@ -246,11 +237,9 @@ impl DataFrame {
             series_cols
         };
 
-        let mut df = DataFrame {
+        Ok(DataFrame {
             columns: series_cols,
-        };
-        df.rechunk();
-        Ok(df)
+        })
     }
 
     /// Removes the last `Series` from the `DataFrame` and returns it, or [`None`] if it is empty.
@@ -488,6 +477,14 @@ impl DataFrame {
         if names.len() != self.columns.len() {
             return Err(PolarsError::ShapeMisMatch("the provided slice with column names has not the same size as the DataFrame's width".into()));
         }
+        let unique_names: AHashSet<&str, ahash::RandomState> =
+            AHashSet::from_iter(names.iter().map(|name| name.as_ref()));
+        if unique_names.len() != self.columns.len() {
+            return Err(PolarsError::SchemaMisMatch(
+                "duplicate column names found".into(),
+            ));
+        }
+
         let columns = mem::take(&mut self.columns);
         self.columns = columns
             .into_iter()
@@ -640,7 +637,6 @@ impl DataFrame {
         for col in columns {
             self.columns.push(col.clone());
         }
-        self.rechunk();
         self
     }
 
@@ -814,13 +810,30 @@ impl DataFrame {
             .zip(df.columns.iter())
             .try_for_each(|(left, right)| {
                 if left.dtype() != right.dtype() || left.name() != right.name() {
-                    return Err(PolarsError::SchemaMisMatch(
-                        format!(
-                            "cannot vstack: schemas don't match of {:?} {:?}",
-                            left, right
-                        )
-                        .into(),
-                    ));
+                    if left.dtype() != right.dtype() {
+                        return Err(PolarsError::SchemaMisMatch(
+                            format!(
+                                "cannot vstack: because column datatypes (dtypes) in the two DataFrames do not match for \
+                                left.name='{}' with left.dtype={} != right.dtype={} with right.name='{}'",
+                                left.name(),
+                                left.dtype(),
+                                right.dtype(),
+                                right.name()
+                            )
+                            .into(),
+                        ));
+                    }
+                    else {
+                        return Err(PolarsError::SchemaMisMatch(
+                            format!(
+                                "cannot vstack: because column names in the two DataFrames do not match for \
+                                left.name='{}' != right.name='{}'",
+                                left.name(),
+                                right.name()
+                            )
+                            .into(),
+                        ));
+                    }
                 }
 
                 left.append(right).expect("should not fail");
@@ -847,10 +860,8 @@ impl DataFrame {
     /// # Ok::<(), PolarsError>(())
     /// ```
     pub fn drop_in_place(&mut self, name: &str) -> Result<Series> {
-        let idx = self.name_to_idx(name)?;
-        let result = Ok(self.columns.remove(idx));
-        self.rechunk();
-        result
+        let idx = self.check_name_to_idx(name)?;
+        Ok(self.columns.remove(idx))
     }
 
     /// Return a new `DataFrame` where all null values are dropped.
@@ -923,7 +934,7 @@ impl DataFrame {
     /// # Ok::<(), PolarsError>(())
     /// ```
     pub fn drop(&self, name: &str) -> Result<Self> {
-        let idx = self.name_to_idx(name)?;
+        let idx = self.check_name_to_idx(name)?;
         let mut new_cols = Vec::with_capacity(self.columns.len() - 1);
 
         self.columns.iter().enumerate().for_each(|(i, s)| {
@@ -938,7 +949,6 @@ impl DataFrame {
     fn insert_at_idx_no_name_check(&mut self, index: usize, series: Series) -> Result<&mut Self> {
         if series.len() == self.height() {
             self.columns.insert(index, series);
-            self.rechunk();
             Ok(self)
         } else {
             Err(PolarsError::ShapeMisMatch(
@@ -955,7 +965,7 @@ impl DataFrame {
     /// Insert a new column at a given index.
     pub fn insert_at_idx<S: IntoSeries>(&mut self, index: usize, column: S) -> Result<&mut Self> {
         let series = column.into_series();
-        self.has_column(series.name())?;
+        self.check_already_present(series.name())?;
         self.insert_at_idx_no_name_check(index, series)
     }
 
@@ -963,12 +973,10 @@ impl DataFrame {
     pub fn with_column<S: IntoSeries>(&mut self, column: S) -> Result<&mut Self> {
         let series = column.into_series();
         if series.len() == self.height() || self.is_empty() {
-            if self.has_column(series.name()).is_err() {
-                let name = series.name().to_string();
-                self.apply(&name, |_| series)?;
+            if let Some(idx) = self.find_idx_by_name(series.name()) {
+                self.replace_at_idx(idx, series)?;
             } else {
                 self.columns.push(series);
-                self.rechunk();
             }
             Ok(self)
         } else {
@@ -1032,6 +1040,71 @@ impl DataFrame {
         self.columns.get_mut(idx)
     }
 
+    /// Select column(s) from this `DataFrame` by range and return a new DataFrame
+    ///
+    /// # Examples
+    ///
+    /// ```rust
+    /// # use polars_core::prelude::*;
+    /// let df = df! {
+    ///     "0" => &[0, 0, 0],
+    ///     "1" => &[1, 1, 1],
+    ///     "2" => &[2, 2, 2]
+    /// }?;
+    ///
+    /// assert!(df.select(&["0", "1"])?.frame_equal(&df.select_by_range(0..=1)?));
+    /// assert!(df.frame_equal(&df.select_by_range(..)?));
+    /// # Ok::<(), PolarsError>(())
+    /// ```
+    pub fn select_by_range<R>(&self, range: R) -> Result<Self>
+    where
+        R: ops::RangeBounds<usize>,
+    {
+        // This function is copied from std::slice::range (https://doc.rust-lang.org/std/slice/fn.range.html)
+        // because it is the nightly feature. We should change here if this function were stable.
+        fn get_range<R>(range: R, bounds: ops::RangeTo<usize>) -> ops::Range<usize>
+        where
+            R: ops::RangeBounds<usize>,
+        {
+            let len = bounds.end;
+
+            let start: ops::Bound<&usize> = range.start_bound();
+            let start = match start {
+                ops::Bound::Included(&start) => start,
+                ops::Bound::Excluded(start) => start.checked_add(1).unwrap_or_else(|| {
+                    panic!("attempted to index slice from after maximum usize");
+                }),
+                ops::Bound::Unbounded => 0,
+            };
+
+            let end: ops::Bound<&usize> = range.end_bound();
+            let end = match end {
+                ops::Bound::Included(end) => end.checked_add(1).unwrap_or_else(|| {
+                    panic!("attempted to index slice up to maximum usize");
+                }),
+                ops::Bound::Excluded(&end) => end,
+                ops::Bound::Unbounded => len,
+            };
+
+            if start > end {
+                panic!("slice index starts at {} but ends at {}", start, end);
+            }
+            if end > len {
+                panic!(
+                    "range end index {} out of range for slice of length {}",
+                    end, len
+                );
+            }
+
+            ops::Range { start, end }
+        }
+
+        let colnames = &self.get_column_names();
+        let range = get_range(range, ..colnames.len());
+
+        self.select(&&colnames[range])
+    }
+
     /// Get column index of a `Series` by name.
     /// # Example
     ///
@@ -1383,7 +1456,7 @@ impl DataFrame {
     /// ```
     /// # use polars_core::prelude::*;
     /// fn example(df: &DataFrame) -> Result<DataFrame> {
-    ///     let idx = UInt32Chunked::new_from_slice("idx", &[0, 1, 9]);
+    ///     let idx = UInt32Chunked::new("idx", &[0, 1, 9]);
     ///     df.take(&idx)
     /// }
     /// ```
@@ -1460,6 +1533,14 @@ impl DataFrame {
         self.select_mut(column)
             .ok_or_else(|| PolarsError::NotFound(name.into()))
             .map(|s| s.rename(name))?;
+
+        let unique_names: AHashSet<&str, ahash::RandomState> =
+            AHashSet::from_iter(self.columns.iter().map(|s| s.name()));
+        if unique_names.len() != self.columns.len() {
+            return Err(PolarsError::SchemaMisMatch(
+                "duplicate column names found".into(),
+            ));
+        }
         Ok(self)
     }
 
@@ -1638,14 +1719,12 @@ impl DataFrame {
     /// | "egg"  | 3     |
     /// +--------+-------+
     /// ```
-    pub fn apply<F, S>(&mut self, column: &str, f: F) -> Result<&mut Self>
+    pub fn apply<F, S>(&mut self, name: &str, f: F) -> Result<&mut Self>
     where
         F: FnOnce(&Series) -> S,
         S: IntoSeries,
     {
-        let idx = self
-            .find_idx_by_name(column)
-            .ok_or_else(|| PolarsError::NotFound(column.to_string()))?;
+        let idx = self.check_name_to_idx(name)?;
         self.apply_at_idx(idx, f)
     }
 
@@ -1722,7 +1801,6 @@ impl DataFrame {
             let col = self.columns.get_unchecked_mut(idx);
             col.rename(&name);
         }
-        self.rechunk();
         Ok(self)
     }
 
@@ -1790,7 +1868,6 @@ impl DataFrame {
             let col = self.columns.get_unchecked_mut(idx);
             col.rename(&name);
         }
-        self.rechunk();
         Ok(self)
     }
 
@@ -2256,11 +2333,11 @@ impl DataFrame {
     }
 
     /// Aggregate the columns to their quantile values.
-    pub fn quantile(&self, quantile: f64) -> Result<Self> {
+    pub fn quantile(&self, quantile: f64, interpol: QuantileInterpolOptions) -> Result<Self> {
         let columns = POOL.install(|| {
             self.columns
                 .par_iter()
-                .map(|s| s.quantile_as_series(quantile))
+                .map(|s| s.quantile_as_series(quantile, interpol))
                 .collect::<Result<Vec<_>>>()
         })?;
         Ok(DataFrame::new_no_checks(columns))
