@@ -56,7 +56,7 @@ where
         (&self.0).into_partial_eq_inner()
     }
 
-    fn vec_hash(&self, random_state: RandomState) -> AlignedVec<u64> {
+    fn vec_hash(&self, random_state: RandomState) -> Vec<u64> {
         self.0.vec_hash(random_state)
     }
 
