@@ -2,6 +2,7 @@
 pub use crate::prelude::ChunkCompare;
 use crate::prelude::*;
 use arrow::array::ArrayRef;
+
 pub(crate) mod arithmetic;
 mod comparison;
 mod from;
@@ -15,7 +16,7 @@ pub mod unstable;
 
 use crate::chunked_array::ops::rolling_window::RollingOptions;
 #[cfg(feature = "rank")]
-use crate::prelude::unique::rank::{rank, RankMethod};
+use crate::prelude::unique::rank::rank;
 #[cfg(feature = "groupby_list")]
 use crate::utils::Wrap;
 use crate::utils::{split_ca, split_series};
@@ -649,8 +650,8 @@ impl Series {
 
     #[cfg(feature = "rank")]
     #[cfg_attr(docsrs, doc(cfg(feature = "rank")))]
-    pub fn rank(&self, method: RankMethod) -> Series {
-        rank(self, method)
+    pub fn rank(&self, options: RankOptions) -> Series {
+        rank(self, options.method, options.descending)
     }
 
     /// Cast throws an error if conversion had overflows
@@ -664,7 +665,7 @@ impl Series {
                     self.dtype(),
                     data_type
                 )
-                .into(),
+                    .into(),
             ))
         } else {
             Ok(s)
@@ -689,6 +690,44 @@ impl Series {
         }
     }
 
+    /// Check if the underlying data is a logical type.
+    pub fn is_logical(&self) -> bool {
+        use DataType::*;
+        matches!(self.dtype(), Date | Datetime | Time | Categorical)
+    }
+
+    /// Check if underlying physical data is numeric.
+    ///
+    /// Date types and Categoricals are also considered numeric.
+    pub fn is_numeric_physical(&self) -> bool {
+        // allow because it cannot be replaced when object feature is activated
+        #[allow(clippy::match_like_matches_macro)]
+        match self.dtype() {
+            DataType::Utf8 | DataType::List(_) | DataType::Boolean | DataType::Null => false,
+            #[cfg(feature = "object")]
+            DataType::Object(_) => false,
+            _ => true,
+        }
+    }
+
+    /// Check if underlying data is numeric
+    pub fn is_numeric(&self) -> bool {
+        // allow because it cannot be replaced when object feature is activated
+        #[allow(clippy::match_like_matches_macro)]
+        match self.dtype() {
+            DataType::Utf8
+            | DataType::List(_)
+            | DataType::Categorical
+            | DataType::Date
+            | DataType::Datetime
+            | DataType::Boolean
+            | DataType::Null => false,
+            #[cfg(feature = "object")]
+            DataType::Object(_) => false,
+            _ => true,
+        }
+    }
+
     #[cfg(feature = "abs")]
     #[cfg_attr(docsrs, doc(cfg(feature = "abs")))]
     /// convert numerical values to their absolute value
@@ -708,7 +747,7 @@ impl Series {
             dt => {
                 return Err(PolarsError::InvalidOperation(
                     format!("abs not supportedd for series of type {:?}", dt).into(),
-                ))
+                ));
             }
         };
         Ok(out)
@@ -742,7 +781,7 @@ where
     fn as_ref(&self) -> &ChunkedArray<T> {
         if &T::get_dtype() == self.dtype() ||
             // needed because we want to get ref of List no matter what the inner type is.
-            (matches!(T::get_dtype(), DataType::List(_)) && matches!(self.dtype(), DataType::List(_)) )
+            (matches!(T::get_dtype(), DataType::List(_)) && matches!(self.dtype(), DataType::List(_)))
         {
             unsafe { &*(self as *const dyn SeriesTrait as *const ChunkedArray<T>) }
         } else {
@@ -762,7 +801,7 @@ where
     fn as_mut(&mut self) -> &mut ChunkedArray<T> {
         if &T::get_dtype() == self.dtype() ||
             // needed because we want to get ref of List no matter what the inner type is.
-            (matches!(T::get_dtype(), DataType::List(_)) && matches!(self.dtype(), DataType::List(_)) )
+            (matches!(T::get_dtype(), DataType::List(_)) && matches!(self.dtype(), DataType::List(_)))
         {
             unsafe { &mut *(self as *mut dyn SeriesTrait as *mut ChunkedArray<T>) }
         } else {
@@ -783,7 +822,7 @@ mod test {
 
     #[test]
     fn cast() {
-        let ar = UInt32Chunked::new_from_slice("a", &[1, 2]);
+        let ar = UInt32Chunked::new("a", &[1, 2]);
         let s = ar.into_series();
         let s2 = s.cast(&DataType::Int64).unwrap();
 
@@ -796,7 +835,7 @@ mod test {
     fn new_series() {
         Series::new("boolean series", &vec![true, false, true]);
         Series::new("int series", &[1, 2, 3]);
-        let ca = Int32Chunked::new_from_slice("a", &[1, 2, 3]);
+        let ca = Int32Chunked::new("a", &[1, 2, 3]);
         ca.into_series();
     }
 
