@@ -6,69 +6,46 @@ use arrow::array::Utf8Array;
 use arrow::bitmap::MutableBitmap;
 use polars_arrow::prelude::FromDataUtf8;
 use polars_core::prelude::*;
-use std::fmt::Debug;
-
-trait ToPolarsError: Debug {
-    fn to_polars_err(&self) -> PolarsError {
-        PolarsError::ComputeError(
-            format!(
-                "Could not parse primitive type during csv parsing: {:?}.\
-                This can occur when a column was inferred as integer type but we stumbled upon a floating point value\
-                You could pass a predefined schema or set `with_ignore_parser_errors` to `true`",
-                self
-            )
-            .into(),
-        )
-    }
-}
-
-impl ToPolarsError for lexical::Error {}
 
 pub(crate) trait PrimitiveParser: PolarsNumericType {
-    fn parse(bytes: &[u8]) -> Result<Self::Native>;
+    fn parse(bytes: &[u8]) -> Option<Self::Native>;
 }
 
 impl PrimitiveParser for Float32Type {
     #[inline]
-    fn parse(bytes: &[u8]) -> Result<f32> {
-        let a = lexical::parse(bytes).map_err(|e| e.to_polars_err())?;
-        Ok(a)
+    fn parse(bytes: &[u8]) -> Option<f32> {
+        lexical::parse(bytes).ok()
     }
 }
 impl PrimitiveParser for Float64Type {
     #[inline]
-    fn parse(bytes: &[u8]) -> Result<f64> {
-        let a = lexical::parse(bytes).map_err(|e| e.to_polars_err())?;
-        Ok(a)
+    fn parse(bytes: &[u8]) -> Option<f64> {
+        lexical::parse(bytes).ok()
     }
 }
 
 impl PrimitiveParser for UInt32Type {
     #[inline]
-    fn parse(bytes: &[u8]) -> Result<u32> {
-        let a = lexical::parse(bytes).map_err(|e| e.to_polars_err())?;
-        Ok(a)
+    fn parse(bytes: &[u8]) -> Option<u32> {
+        lexical::parse(bytes).ok()
     }
 }
 impl PrimitiveParser for UInt64Type {
     #[inline]
-    fn parse(bytes: &[u8]) -> Result<u64> {
-        let a = lexical::parse(bytes).map_err(|e| e.to_polars_err())?;
-        Ok(a)
+    fn parse(bytes: &[u8]) -> Option<u64> {
+        lexical::parse(bytes).ok()
     }
 }
 impl PrimitiveParser for Int32Type {
     #[inline]
-    fn parse(bytes: &[u8]) -> Result<i32> {
-        let a = lexical::parse(bytes).map_err(|e| e.to_polars_err())?;
-        Ok(a)
+    fn parse(bytes: &[u8]) -> Option<i32> {
+        lexical::parse(bytes).ok()
     }
 }
 impl PrimitiveParser for Int64Type {
     #[inline]
-    fn parse(bytes: &[u8]) -> Result<i64> {
-        let a = lexical::parse(bytes).map_err(|e| e.to_polars_err())?;
-        Ok(a)
+    fn parse(bytes: &[u8]) -> Option<i64> {
+        lexical::parse(bytes).ok()
     }
 }
 
@@ -77,7 +54,6 @@ trait ParsedBuffer<T> {
         &mut self,
         bytes: &[u8],
         ignore_errors: bool,
-        start_pos: usize,
         _needs_escaping: bool,
     ) -> Result<()>;
 }
@@ -91,23 +67,20 @@ where
         &mut self,
         bytes: &[u8],
         ignore_errors: bool,
-        _start_pos: usize,
         _needs_escaping: bool,
     ) -> Result<()> {
         if bytes.is_empty() {
             self.append_null()
         } else {
             let bytes = drop_quotes(bytes);
+            // legacy comment (remember this if you decide to use Results again):
             // its faster to work on options.
             // if we need to throw an error, we parse again to be able to throw the error
-            let result = T::parse(bytes).ok();
 
-            match (result, ignore_errors) {
+            match (T::parse(bytes), ignore_errors) {
                 (Some(value), _) => self.append_value(value),
                 (None, true) => self.append_null(),
-                (None, _) => {
-                    T::parse(bytes)?;
-                }
+                (None, _) => return Err(PolarsError::ComputeError("".into())),
             };
         }
         Ok(())
@@ -159,7 +132,6 @@ impl ParsedBuffer<Utf8Type> for Utf8Field {
         &mut self,
         bytes: &[u8],
         ignore_errors: bool,
-        _start_pos: usize,
         needs_escaping: bool,
     ) -> Result<()> {
         // Only for lossy utf8 we check utf8 now. Otherwise we check all utf8 at the end.
@@ -224,7 +196,6 @@ impl ParsedBuffer<BooleanType> for BooleanChunkedBuilder {
         &mut self,
         bytes: &[u8],
         ignore_errors: bool,
-        start_pos: usize,
         _needs_escaping: bool,
     ) -> Result<()> {
         if bytes.eq_ignore_ascii_case(b"false") {
@@ -236,8 +207,7 @@ impl ParsedBuffer<BooleanType> for BooleanChunkedBuilder {
         } else {
             return Err(PolarsError::ComputeError(
                 format!(
-                    "Error while parsing value {} at byte position {} as boolean",
-                    start_pos,
+                    "Error while parsing value {} as boolean",
                     String::from_utf8_lossy(bytes)
                 )
                 .into(),
@@ -395,12 +365,24 @@ impl Buffer {
         };
     }
 
+    pub(crate) fn dtype(&self) -> DataType {
+        match self {
+            Buffer::Boolean(_) => DataType::Boolean,
+            Buffer::Int32(_) => DataType::Int32,
+            Buffer::Int64(_) => DataType::Int64,
+            Buffer::UInt32(_) => DataType::UInt32,
+            Buffer::UInt64(_) => DataType::UInt64,
+            Buffer::Float32(_) => DataType::Float32,
+            Buffer::Float64(_) => DataType::Float64,
+            Buffer::Utf8(_) => DataType::Utf8,
+        }
+    }
+
     #[inline]
     pub(crate) fn add(
         &mut self,
         bytes: &[u8],
         ignore_errors: bool,
-        start_pos: usize,
         needs_escaping: bool,
     ) -> Result<()> {
         use Buffer::*;
@@ -409,7 +391,6 @@ impl Buffer {
                 buf,
                 bytes,
                 ignore_errors,
-                start_pos,
                 needs_escaping,
             ),
             Int32(buf) => {
@@ -417,7 +398,6 @@ impl Buffer {
                     buf,
                     bytes,
                     ignore_errors,
-                    start_pos,
                     needs_escaping,
                 )
             }
@@ -426,7 +406,6 @@ impl Buffer {
                     buf,
                     bytes,
                     ignore_errors,
-                    start_pos,
                     needs_escaping,
                 )
             }
@@ -435,7 +414,6 @@ impl Buffer {
                     buf,
                     bytes,
                     ignore_errors,
-                    start_pos,
                     needs_escaping,
                 )
             }
@@ -444,7 +422,6 @@ impl Buffer {
                     buf,
                     bytes,
                     ignore_errors,
-                    start_pos,
                     needs_escaping,
                 )
             }
@@ -453,7 +430,6 @@ impl Buffer {
                     buf,
                     bytes,
                     ignore_errors,
-                    start_pos,
                     needs_escaping,
                 )
             }
@@ -462,7 +438,6 @@ impl Buffer {
                     buf,
                     bytes,
                     ignore_errors,
-                    start_pos,
                     needs_escaping,
                 )
             }
@@ -470,7 +445,6 @@ impl Buffer {
                 buf,
                 bytes,
                 ignore_errors,
-                start_pos,
                 needs_escaping,
             ),
         }
