@@ -10,9 +10,9 @@ use crate::logical_plan::optimizer::simplify_expr::SimplifyExprRule;
 use crate::logical_plan::optimizer::stack_opt::{OptimizationRule, StackOptimizer};
 use crate::prelude::*;
 use polars_core::chunked_array::builder::get_list_builder;
+use polars_core::df;
 #[cfg(feature = "temporal")]
 use polars_core::export::chrono::{NaiveDate, NaiveDateTime, NaiveTime};
-use polars_core::{df, prelude::*};
 use std::iter::FromIterator;
 
 fn scan_foods_csv() -> LazyFrame {
