@@ -24,8 +24,8 @@ def test_apply_none() -> None:
     assert out[0].to_list() == [4.75, 326.75, 82.75]
     assert out[1].to_list() == [238.75, 3418849.75, 372.75]
 
-    out = df.select(pl.map(exprs=["a", "b"], f=lambda s: s[0] * s[1]))
-    assert out["a"].to_list() == (df["a"] * df["b"]).to_list()
+    out_df = df.select(pl.map(exprs=["a", "b"], f=lambda s: s[0] * s[1]))
+    assert out_df["a"].to_list() == (df["a"] * df["b"]).to_list()
 
     # check if we can return None
     def func(s: List) -> Optional[int]:
