@@ -1,5 +1,5 @@
 from datetime import date, datetime
-from typing import Any, Sequence
+from typing import Any, Union
 
 import numpy as np
 import pandas as pd
@@ -302,7 +302,7 @@ def test_set_np_array(dtype: Any) -> None:
 
 
 @pytest.mark.parametrize("idx", [[0, 2], (0, 2)])
-def test_set_list_and_tuple(idx: Sequence) -> None:
+def test_set_list_and_tuple(idx: Union[list, tuple]) -> None:
     a = pl.Series("a", [1, 2, 3])
     a[idx] = 4
     testing.assert_series_equal(a, pl.Series("a", [4, 2, 4]))
@@ -1117,6 +1117,10 @@ def test_compare_series_type_mismatch() -> None:
     with pytest.raises(AssertionError, match="Series are different\n\nType mismatch"):
         testing.assert_series_equal(srs1, srs2)  # type: ignore
 
+    srs3 = pl.Series([1.0, 2.0, 3.0])
+    with pytest.raises(AssertionError, match="Series are different\n\nDtype mismatch"):
+        testing.assert_series_equal(srs1, srs3)
+
 
 def test_compare_series_name_mismatch() -> None:
     srs1 = pl.Series(values=[1, 2, 3], name="srs1")
