@@ -1,3 +1,5 @@
+from typing import Type
+
 import numpy as np
 import pytest
 
@@ -5,17 +7,21 @@ import polars as pl
 
 
 @pytest.mark.parametrize("dtype", [pl.Float32, pl.Float64, pl.Int32])
-def test_std(dtype):
+def test_std(dtype: Type[pl.DataType]) -> None:
     if dtype == pl.Int32:
-        values = [1, 2, 3, 4]
+        df = pl.DataFrame(
+            [
+                pl.Series("groups", ["a", "a", "b", "b"]),
+                pl.Series("values", [1, 2, 3, 4], dtype=dtype),
+            ]
+        )
     else:
-        values = [1.0, 2.0, 3.0, 4.0]
-    df = pl.DataFrame(
-        [
-            pl.Series("groups", ["a", "a", "b", "b"]),
-            pl.Series("values", values, dtype=dtype),
-        ]
-    )
+        df = pl.DataFrame(
+            [
+                pl.Series("groups", ["a", "a", "b", "b"]),
+                pl.Series("values", [1.0, 2.0, 3.0, 4.0], dtype=dtype),
+            ]
+        )
 
     out = df.select(pl.col("values").std().over("groups"))
     assert np.isclose(out["values"][0], 0.7071067690849304)
